@@ -30,20 +30,13 @@ import fontcontrol
 iPC = pathcontrol.PathControl() #Make an instance - hence the small 'i'
 
 ##  Borrowed from wxglade.py
-## This works, but sys.path[0] might work too ... 
-def determine_fontypython_path():
-    try:
-        root = __file__
-        if os.path.islink(root):
-            root = os.path.realpath(root)
-##        print "*DEBUG:"
-##        print "determine_fontypython_path:"
-##        print os.path.dirname(os.path.abspath(root)) 
-##        print "sys.path[0]", sys.path[0]
-        return os.path.dirname(os.path.abspath(root)) 
-    except:
-        print _("I'm sorry, but something is wrong.\nThere is no __file__ variable. Please panic.")
-        raise SystemExit
+## The reason for this is to find the path of this file
+## when it's called from an import somewhere else.
+## There is no sys.argv[0] in this case.
+root = __file__
+if os.path.islink(root):
+    root = os.path.realpath(root)
+fontyroot = os.path.dirname(os.path.abspath(root)) 
 
 ####
 ## True if a folder. False if not - but that does not mean it's a pog.
@@ -96,8 +89,8 @@ class FPState:
         
 state = FPState() #The only instance of the state object -- app-wide
 
-## Where my png images are.
-mythingsdir = determine_fontypython_path()  + "/things/" #point it at things/ folder
+## Where my images and things are.
+mythingsdir = os.path.join(fontyroot,"things/")
 
 ####
 ## Save and Load the conf file
