@@ -179,7 +179,7 @@ If you want to backup your pogs, that's where ya go.
 %(copy)s""") % { "c":"fontypython", "folder":_pc.appPath(), "contact":contact, "copy":copyright }
 
 ## These two are used in setup.py
-description = _("Fonty Python - manage fonts on Gnu/Linux")
+description = _("Fonty Python - view and manage all kinds of fonts on Gnu/Linux")
 long_description = _("""Manage your fonts on Gnu/Linux.
 NEWS : We now support TTF, OTF, Type1 (PFB, PFM) 
 and TTC fonts.
