@@ -172,7 +172,7 @@ class Fitmap(wx.lib.statbmp.GenStaticBitmap):
         
         if self.fitem.badfont:
             ## We have a badstyle to help us differentiate these.
-            ## I am only treat PIL_IO_ERROR, PIL_CANNOT_RENDER and PIL_UNICODE_ERROR
+            ## I will treat PIL_IO_ERROR, PIL_CANNOT_RENDER and PIL_UNICODE_ERROR
             ## as the same thing : they all mean we can use the font item, just not
             ## actually see the typeface.
             lineCol = (0,0,0)
@@ -317,12 +317,14 @@ class Fitmap(wx.lib.statbmp.GenStaticBitmap):
 
     def __fatFont(self, dc, x, y, fcol, bcol, points, weight, txt):
         """
-        Draw a string with a backdrop highlight. Makes it "fat"
+        Draw a string with a backdrop highlight. Makes it "fat".
         I suppose I should draw one string, then try blitting it around 
         rather than DrawTexting it. Later ...
         """
-        dc.SetFont(wx.Font(points, family=wx.SWISS, style=wx.NORMAL, weight=weight, underline=False) ) 
-        #Draw the back-drop text
+        dc.SetFont\
+        (wx.Font(points, family=wx.SWISS, style=wx.NORMAL, weight=weight, underline=False) ) 
+        
+        ## Draw the back-drop text
         dc.SetTextForeground(bcol)
         dc.DrawText(txt, x-1, y-1)
         dc.DrawText(txt, x-1, y+1)
@@ -333,7 +335,7 @@ class Fitmap(wx.lib.statbmp.GenStaticBitmap):
         dc.DrawText(txt, x-1, y)
         dc.DrawText(txt, x+1, y)
         dc.DrawText(txt, x, y+1)
-        #Final text
+        ## Final text
         dc.SetTextForeground(fcol)
         dc.DrawText(txt, x, y)
 
@@ -343,19 +345,14 @@ class Fitmap(wx.lib.statbmp.GenStaticBitmap):
         Dump the bitmap to the screen.
         """
         if self.bitmap:
-            # Create a buffered paint DC.  It will create the real
-            # wx.PaintDC and then blit the bitmap to it when dc is
-            # deleted.  Since we don't need to draw anything else
-            # here that's all there is to it.
+            ## Create a buffered paint DC.  It will create the real
+            ## wx.PaintDC and then blit the bitmap to it when dc is
+            ## deleted.  Since we don't need to draw anything else
+            ## here that's all there is to it.
             dc = wx.BufferedPaintDC(self, self.bitmap, wx.BUFFER_VIRTUAL_AREA)
 
 
     def __onClick(self, event) :
-##        print "CLICK"
-##        print "self.fitem.badfont :", self.fitem.badfont 
-##        print "fpsys.state.cantick :", fpsys.state.cantick 
-##        print "self.fitem.inactive :", self.fitem.inactive
-            
         if fpsys.state.cantick and not self.fitem.inactive:
             self.fitem.ticked = not(self.fitem.ticked)
             self.prepareBitmap() # This only redraws a single font item.
@@ -445,7 +442,7 @@ class ScrolledFontView(wx.lib.scrolledpanel.ScrolledPanel) :
         global firstRunSizeFlag
         if not firstRunSizeFlag:
             firstRunSizeFlag = True
-            self.width = 1024 # Cannot get a sensible value for 1st run.
+            self.width = 1024 # I cannot get a sensible value for 1st run.
         else:
             self.width = self.DoGetSize()[0] - sbwidth
 
@@ -524,7 +521,7 @@ class FontViewPanel(wx.Panel):
         sizerOtherControls.Add(( 4,-1), 0, wx.EXPAND)
         sizerOtherControls.Add(self.choicePage, 0 ,wx.EXPAND | wx.ALIGN_RIGHT)  #Added it to the sizer
         
-        ## The FONT panell:
+        ## The FONT panel:
         self.scrolledFontView = ScrolledFontView(self) 
         
         buttonsSizer = wx.BoxSizer(wx.HORIZONTAL) 
@@ -963,8 +960,7 @@ class TargetPogChooser(wx.Panel):
         if e.GetId() == self.idpurge:
             if not fpsys.state.targetobject.isInstalled():
                 pogname = fpsys.state.targetobject.name
-                dlg = wx.MessageDialog(self,_("Do you want to purge %s?\n\nPurging means all the fonts in the pog\nthat are not pointing to actual files\nwill be removed from this pog.") % pogname\
-                ,_("Purge font?"), wx.YES_NO | wx.ICON_INFORMATION )
+                dlg = wx.MessageDialog(self,_("Do you want to purge %s?\n\nPurging means all the fonts in the pog\nthat are not pointing to actual files\nwill be removed from this pog.") % pogname, _("Purge font?"), wx.YES_NO | wx.ICON_INFORMATION )
                 if dlg.ShowModal() == wx.ID_YES:
                     ## pog.purge() Raises
                     ##          PogEmpty
@@ -1100,7 +1096,9 @@ class PogChooser(wx.ListCtrl) :
         png = wx.Bitmap( fpsys.mythingsdir + "/pog16x16.target.png", wx.BITMAP_TYPE_PNG )
         il.Add( png )
         
-        wx.ListCtrl.__init__(self,parent,-1, style=wx.LC_LIST | wx.LC_AUTOARRANGE | wx.LC_SORT_ASCENDING) 
+        wx.ListCtrl.__init__\
+        (self,parent,-1, style=wx.LC_LIST | wx.LC_AUTOARRANGE | wx.LC_SORT_ASCENDING) 
+        
         self.AssignImageList(il, wx.IMAGE_LIST_SMALL) 
 
         self.__PC = pathcontrol.PathControl()
@@ -1169,7 +1167,6 @@ class PogChooser(wx.ListCtrl) :
             for x in range(0, c):
                 i = self.GetItem(x, 0)
                 ## Must make a tmp Pog before I can test installed status.
-                
                 tmpPog = fontcontrol.Pog(i.GetText())
                 if tmpPog.isInstalled():
                     self.SetItemImage(x, 1)
@@ -1246,7 +1243,7 @@ class PogChooser(wx.ListCtrl) :
         row = self.FindItem(-1, pogname)
         id = self.GetItemData(row)
         self.DeleteItem(row)
-        del( self.__poglistCopy[id] ) # cull from our private store too.
+        del( PogChooser.__poglistCopy[id] ) # cull from our private store too.
 
     def ClearSelection(self):
         self.Select(self.indexselected, False)
@@ -1290,11 +1287,13 @@ class DirControl(wx.GenericDirCtrl) :
         else: 
             ##Let's get it from the config object
             lastdir = fpsys.config.lastdir
+            
             if os.path.exists(lastdir):
                 startdir = lastdir
             else:
                 startdir = os.environ['HOME']
         wx.GenericDirCtrl.__init__(self, parent, -1, dir = startdir, style=wx.DIRCTRL_DIR_ONLY)
+##        self.ShowHidden( True )
         
         ## Weird step:
         self.tree = self.GetTreeCtrl() 
@@ -1401,13 +1400,11 @@ class NoteBook(wx.Notebook):
             ps.pub(show_error_and_abort, unicode( e ))
             return
         if fpsys.state.samepogs: #forbid same pogs selection
-            #ps.pub(print_to_status_bar, "Pog already selected in the View")
             ps.pub(select_no_target_pog)
         else:
             ps.pub(reset_to_page_one)
         ps.pub(update_font_view)
     
-    ## Public Interface:
     def AddItem(self, pogname):
         self.listctrl.AddItem(pogname)
     def RemoveItem(self, pogname):
@@ -1421,7 +1418,6 @@ class NoteBook(wx.Notebook):
         fpsys.SetViewPogToEmpty()
         wx.EndBusyCursor()
         
-
 class StatusBar(wx.StatusBar):
     """
     The status bar
@@ -1432,7 +1428,6 @@ class StatusBar(wx.StatusBar):
         self.SetStatusText( _("Welcome to Fonty Python version %s") % fpversion.version, 0)
     def Report(self, msg):
         self.SetStatusText(msg, 0)
-        
 
 class MainFrame(wx.Frame):
     def __init__(self,parent,title) :
@@ -1490,11 +1485,6 @@ class MainFrame(wx.Frame):
         self.Bind(wx.EVT_MENU, self.__menuAbout, id = 202)
         self.Bind(wx.EVT_MENU, self.__menuHelp, id = 201)
 
-        ## Dec 2007 - subscribe before we create the panelFontView
-        ## Because the panelFontView asks for a var from this func.
-        ## Just plain not working.
-##        ps.sub(get_font_view_width, self.GetFVWidth)
-
         ## Create a splitter 
         self.splitter = Splitter(self) 
     
@@ -1591,37 +1581,6 @@ class MainFrame(wx.Frame):
         """
         ps.pub( update_font_view ) # starts a chain of calls.
         
-##    def GetFVWidth( self, args=None ): 
-##        ## Trying to dynamically set the width of each fitem with this value:
-##        #global firstRunSizeFlag
-##        #if not firstRunSizeFlag:
-##            #firstRunSizeFlag = True
-##            # You can tell, I have been searching for a way to detect the 
-##            # startup size of the area where the fonts get drawn.
-##            # nothing I have tried works... :|
-##            # I am going to just plain declare 1024 as the width on first run.
-####            print "ONCE OFF:"
-####            print "??:", self.splitter.SashPosition#.GetClientSize()[0]
-####            print "splitter2:", self.splitter2.SashPosition
-####            print "splitter:", self.splitter.Size# dir(self.splitter2)#.SashPosition
-####            print "splitter2:", self.splitter2.Size# dir(self.splitter2)#.SashPosition
-####            print "self:", self.GetSize()
-####            print "panelNotebook:", self.panelNotebook.GetSize()
-####            print "panelTargetPogChooser:", self.panelTargetPogChooser.GetSize()
-####            print dir(self.sizerFontView)
-####            print "sizer:", self.sizerFontView.Size
-####            print "splitter.SashPosition:", self.splitter.SashPosition
-####            print "splitter2.SashPosition:", self.splitter2.SashPosition
-####            print "splitter 1:", self.splitter.GetWindow1().GetSize()
-####            print "splitter 2:", self.splitter.GetWindow2().GetSize()
-####            print "splitter2 1:", self.splitter2.GetWindow1().GetSize()
-####            print "splitter2 2:", self.splitter2.GetWindow2().GetSize()
-####            print "::", self.panelFontView.sizerFontView.GetSize()
-####            print "::", self.panelFontView.scrolledFontView.GetSize()
-##            #return 1024
-##        ## After the first-run, this seems to work fine.
-##        return self.splitter2.SashPosition # - 22
-        
     def GetSashesPos( self, args=None ):
         ## For saving/restoring the sashes to where we bloody left them :\
         return ( self.splitter.GetSashPosition(), self.panelTargetPogChooser.GetClientSize()[0])
@@ -1688,9 +1647,10 @@ class MainFrame(wx.Frame):
         try:
             fpsys.state.targetobject.uninstall()
         except (fontybugs.PogEmpty, 
-                        fontybugs.PogNotInstalled, #This one is prevented by the buttons greying out in the gui
+                        fontybugs.PogNotInstalled, 
                         fontybugs.PogLinksRemain
                      ), e:
+            ## PogNotInstalled is prevented by buttons greying out in the gui.
             self.ErrorBox([unicode( e ),])
             return
         ## Update GUI
@@ -1774,7 +1734,7 @@ class MainFrame(wx.Frame):
     def __endApp(self) :
         """
         Save app's vital statistics and exit.
-        See the end of start.py too.
+        See the end of start.py where it's actually saved.
         """
         fpsys.config.pos = self.GetPositionTuple() 
         ## Dec 2007 - I was using the wring func and the
